package # Hide from pause
   SampleApp;

use strict;
use warnings;

use Catalyst::Runtime '5.70';
use Catalyst qw/-Debug/;

our $VERSION = '0.01';

1;
